# Keyboard press count and Mouse event count 

A Python package which will hepls you to get summary report of any webpage content or simply pass some content and get summary

## Usage


```
simply import 

from createsummary import create_SUMMARY

AND THEN

pass some text over

create_SUMMARY(text)

```
# Get Summary
